@@ -27,9 +27,9 @@ class KCMComponentChooser : public KCModule
 public:
     KCMComponentChooser(QWidget *parent, const QVariantList &args);
 
-    void load() Q_DECL_OVERRIDE;
-    void save() Q_DECL_OVERRIDE;
-    void defaults() Q_DECL_OVERRIDE;
+    void load() override;
+    void save() override;
+    void defaults() override;
 
 private:
     ComponentChooser  *m_chooser;
